export type ValidatedControlProps<V> = {
    /**
     * Whether the control is required.
     * @default false
     */
    required?: boolean;
    /**
     * Label the control as "optional" when _not_ `required`, instead of the inverse.
     * @default false
     */
    markWhenOptional?: boolean;
    /**
     * A function that returns a custom validity message when applicable. This error message will be applied to the
     * underlying element using the native [`setCustomValidity()` method](https://developer.mozilla.org/en-US/docs/Web/API/HTMLObjectElement/setCustomValidity).
     * This means the custom validator will be run _in addition_ to any other HTML attribute-based validation, and
     * will be prioritized over any existing validity messages dictated by the HTML attributes.
     * An empty string or `undefined` return value will clear any existing custom validity message.
     *
     * Make sure you don't programatically pass a value (such as an initial value) to the control component
     * that fails this validator, because the validator will only run for user-initiated changes.
     *
     * Always prefer using standard HTML attributes like `required` and `min`/`max` over custom validators
     * when possible, as they are simpler and have localized error messages built in.
     */
    customValidator?: (currentValue: V) => string | void;
};
//# sourceMappingURL=types.d.ts.map